@@ -28,18 +28,6 @@
 #include <sparse/DotIO.h>
 #include <sparse/colorutil.h>
 
-#ifdef _WIN32 /*dependencies*/
-    #pragma comment( lib, "cgraph.lib" )
-    #pragma comment( lib, "gvc.lib" )
-    #pragma comment( lib, "ingraphs.lib" )
-    #pragma comment( lib, "sparse.lib" )
-    #pragma comment( lib, "sfdp.lib" )
-    #pragma comment( lib, "edgepaintlib.lib" )
-    #pragma comment( lib, "neatogen.lib" )
-    #pragma comment( lib, "rbtree.lib" )
-    #pragma comment( lib, "cdt.lib" )
-#endif   /* not _WIN32 */
-
 typedef struct {
   FILE* outfp;
   char** infiles;
@@ -126,11 +114,6 @@ static void init(int argc, char *argv[], opts_t* opts) {
     opts->infiles = NULL;
 }
 
-static Agraph_t *gread(FILE * fp)
-{
-    return agread(fp, NULL);
-}
-
 static void clusterGraph (Agraph_t* g, int maxcluster, int clustering_method){
   initDotIO(g);
   attached_clustering(g, maxcluster, clustering_method);
@@ -144,7 +127,7 @@ int main(int argc, char *argv[])
 
   init(argc, argv, &opts);
 
-  newIngraph (&ig, opts.infiles, gread);
+  newIngraph(&ig, opts.infiles);
 
   while ((g = nextGraph (&ig)) != 0) {
     if (prevg) agclose (prevg);
