@@ -581,7 +581,7 @@ static int processClusters(Agraph_t * g, char* graphName)
 	    out = agsubg(g, name, 1);
 	    agxbfree(&buf);
 	}
-	aginit(out, AGRAPH, "graphinfo", sizeof(Agraphinfo_t), TRUE);
+	aginit(out, AGRAPH, "graphinfo", sizeof(Agraphinfo_t), true);
 	GD_cc_subg(out) = 1;
 	dn = ND_dn(n);
 	n_cnt = dfs(dg, dn, dout);
@@ -610,7 +610,7 @@ static int processClusters(Agraph_t * g, char* graphName)
 	    out = agsubg(g, name, 1);
 	    agxbfree(&buf);
 	}
-	aginit(out, AGRAPH, "graphinfo", sizeof(Agraphinfo_t), TRUE);
+	aginit(out, AGRAPH, "graphinfo", sizeof(Agraphinfo_t), true);
 	GD_cc_subg(out) = 1;
 	n_cnt = dfs(dg, dn, dout);
 	unionNodes(dout, out);
@@ -677,7 +677,7 @@ bindGraphinfo (Agraph_t * g)
 {
     Agraph_t *subg;
 
-    aginit(g, AGRAPH, "graphinfo", sizeof(Agraphinfo_t), TRUE);
+    aginit(g, AGRAPH, "graphinfo", sizeof(Agraphinfo_t), true);
     for (subg = agfstsubg(g); subg; subg = agnxtsubg(subg)) {
 	bindGraphinfo (subg);
     }
@@ -693,7 +693,7 @@ static int process(Agraph_t * g, char* graphName)
     Agnode_t *n;
     int extracted = 0;
 
-    aginit(g, AGNODE, "nodeinfo", sizeof(Agnodeinfo_t), TRUE);
+    aginit(g, AGNODE, "nodeinfo", sizeof(Agnodeinfo_t), true);
     bindGraphinfo (g);
 
     if (useClusters)
@@ -713,7 +713,7 @@ static int process(Agraph_t * g, char* graphName)
 	    out = agsubg(g, agxbuse(&name), 1);
 	    agxbfree(&name);
 	}
-	aginit(out, AGRAPH, "graphinfo", sizeof(Agraphinfo_t), TRUE);
+	aginit(out, AGRAPH, "graphinfo", sizeof(Agraphinfo_t), true);
 	GD_cc_subg(out) = 1;
 	n_cnt = dfs(g, n, out);
 	if (doEdges)
@@ -738,7 +738,7 @@ static int process(Agraph_t * g, char* graphName)
 	    out = agsubg(g, agxbuse(&name), 1);
 	    agxbfree(&name);
 	}
-	aginit(out, AGRAPH, "graphinfo", sizeof(Agraphinfo_t), TRUE);
+	aginit(out, AGRAPH, "graphinfo", sizeof(Agraphinfo_t), true);
 	GD_cc_subg(out) = 1;
 	n_cnt = dfs(g, n, out);
 	if (doEdges)
@@ -795,11 +795,6 @@ static int process(Agraph_t * g, char* graphName)
     return c_cnt > 1;
 }
 
-static Agraph_t *gread(FILE * fp)
-{
-    return agread(fp, NULL);
-}
-
 /* chkGraphName:
  * If the graph is anonymous, its name starts with '%'.
  * If we use this as the prefix for subgraphs, they will not be
@@ -814,20 +809,13 @@ static Agraph_t *gread(FILE * fp)
 static char*
 chkGraphName (Agraph_t* g)
 {
-    static char* buf = NULL;
-    static size_t buflen = 0;
+    static agxbuf buf;
     char* s = agnameof(g);
 
     if (*s != '%') return s;
-    size_t len = strlen(s) + 2;   /* plus '\0' and '_' */
-    if (len > buflen) {
-	buf = gv_realloc(buf, buflen, len);
-	buflen = len;
-    }
-    buf[0] = '_';
-    strcpy (buf+1, s);
+    agxbprint(&buf, "_%s", s);
 
-    return buf;
+    return agxbuse(&buf);
 }
 
 int main(int argc, char *argv[])
@@ -836,7 +824,7 @@ int main(int argc, char *argv[])
     ingraph_state ig;
     int r = 0;
     init(argc, argv);
-    newIngraph(&ig, Files, gread);
+    newIngraph(&ig, Files);
 
     while ((g = nextGraph(&ig)) != 0) {
 	r += process(g, chkGraphName(g));
