@@ -92,13 +92,10 @@ static gmledge* E;
 static Dt_t* L;
 static gv_stack_t liststk;
 
-static void free_attr (Dt_t*d, gmlattr* p, Dtdisc_t* ds); /* forward decl */
+static void free_attr(gmlattr *p, Dtdisc_t *ds);
 static char *sortToStr(unsigned short sort);
 
-static void
-free_node (Dt_t*d, gmlnode* p, Dtdisc_t* ds)
-{
-    (void)d;
+static void free_node(gmlnode *p, Dtdisc_t *ds) {
     (void)ds;
 
     if (!p) return;
@@ -106,10 +103,7 @@ free_node (Dt_t*d, gmlnode* p, Dtdisc_t* ds)
     free (p);
 }
 
-static void
-free_edge (Dt_t*d, gmledge* p, Dtdisc_t* ds)
-{
-    (void)d;
+static void free_edge(gmledge *p, Dtdisc_t *ds) {
     (void)ds;
 
     if (!p) return;
@@ -117,10 +111,7 @@ free_edge (Dt_t*d, gmledge* p, Dtdisc_t* ds)
     free (p);
 }
 
-static void
-free_graph (Dt_t*d, gmlgraph* p, Dtdisc_t* ds)
-{
-    (void)d;
+static void free_graph(gmlgraph *p, Dtdisc_t *ds) {
     (void)ds;
 
     if (!p) return;
@@ -176,15 +167,15 @@ cleanup (void)
 	L = NULL;
     }
     if (N) {
-	free_node (0, N, 0);
+	free_node(N, 0);
 	N = NULL;
     }
     if (E) {
-	free_edge (0, E, 0);
+	free_edge(E, 0);
 	E = NULL;
     }
     if (G) {
-	free_graph (0, G, 0);
+	free_graph(G, 0);
 	G = NULL;
     }
 }
@@ -304,7 +295,7 @@ setDir (char* d)
 }
 
 
-#line 308 "gmlparse.c"
+#line 299 "gmlparse.c"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -432,7 +423,7 @@ extern int gmldebug;
 #if ! defined GMLSTYPE && ! defined GMLSTYPE_IS_DECLARED
 union GMLSTYPE
 {
-#line 248 "../../cmd/tools/gmlparse.y"
+#line 239 "../../cmd/tools/gmlparse.y"
 
     int i;
     char *str;
@@ -441,7 +432,7 @@ union GMLSTYPE
     gmlattr* ap;
     Dt_t*    list;
 
-#line 445 "gmlparse.c"
+#line 436 "gmlparse.c"
 
 };
 typedef union GMLSTYPE GMLSTYPE;
@@ -819,13 +810,13 @@ static const yytype_int8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_int16 yyrline[] =
 {
-       0,   271,   271,   272,   273,   276,   279,   282,   283,   286,
-     287,   290,   291,   292,   293,   300,   301,   304,   304,   307,
-     308,   311,   312,   315,   315,   318,   319,   322,   323,   324,
-     325,   328,   328,   331,   332,   335,   336,   339,   340,   341,
-     342,   343,   344,   345,   346,   347,   348,   349,   350,   351,
-     352,   353,   354,   355,   356,   357,   358,   359,   360,   361,
-     362,   363,   364,   365
+       0,   262,   262,   263,   264,   267,   270,   273,   274,   277,
+     278,   281,   282,   283,   284,   291,   292,   295,   295,   298,
+     299,   302,   303,   306,   306,   309,   310,   313,   314,   315,
+     316,   319,   319,   322,   323,   326,   327,   330,   331,   332,
+     333,   334,   335,   336,   337,   338,   339,   340,   341,   342,
+     343,   344,   345,   346,   347,   348,   349,   350,   351,   352,
+     353,   354,   355,   356
 };
 #endif
 
@@ -1707,37 +1698,37 @@ yyreduce:
   switch (yyn)
     {
   case 2:
-#line 271 "../../cmd/tools/gmlparse.y"
+#line 262 "../../cmd/tools/gmlparse.y"
                            {gmllexeof(); if (G->parent) popG(); }
-#line 1713 "gmlparse.c"
+#line 1704 "gmlparse.c"
     break;
 
   case 3:
-#line 272 "../../cmd/tools/gmlparse.y"
+#line 263 "../../cmd/tools/gmlparse.y"
               { cleanup(); YYABORT; }
-#line 1719 "gmlparse.c"
+#line 1710 "gmlparse.c"
     break;
 
   case 5:
-#line 276 "../../cmd/tools/gmlparse.y"
+#line 267 "../../cmd/tools/gmlparse.y"
               { pushG(); }
-#line 1725 "gmlparse.c"
+#line 1716 "gmlparse.c"
     break;
 
   case 11:
-#line 290 "../../cmd/tools/gmlparse.y"
+#line 281 "../../cmd/tools/gmlparse.y"
                  { dtinsert (G->nodelist, (yyvsp[0].np)); }
-#line 1731 "gmlparse.c"
+#line 1722 "gmlparse.c"
     break;
 
   case 12:
-#line 291 "../../cmd/tools/gmlparse.y"
+#line 282 "../../cmd/tools/gmlparse.y"
                  { dtinsert (G->edgelist, (yyvsp[0].ep)); }
-#line 1737 "gmlparse.c"
+#line 1728 "gmlparse.c"
     break;
 
   case 14:
-#line 293 "../../cmd/tools/gmlparse.y"
+#line 284 "../../cmd/tools/gmlparse.y"
                              { 
 		if (setDir((yyvsp[0].str))) { 
 		    yyerror("mixed directed and undirected graphs"); 
@@ -1745,269 +1736,269 @@ yyreduce:
 		    YYABORT;
 		}
 	  }
-#line 1749 "gmlparse.c"
+#line 1740 "gmlparse.c"
     break;
 
   case 15:
-#line 300 "../../cmd/tools/gmlparse.y"
+#line 291 "../../cmd/tools/gmlparse.y"
                        { dtinsert (G->attrlist, mkAttr(gv_strdup("id"), 0, INTEGER, (yyvsp[0].str), 0)); }
-#line 1755 "gmlparse.c"
+#line 1746 "gmlparse.c"
     break;
 
   case 16:
-#line 301 "../../cmd/tools/gmlparse.y"
+#line 292 "../../cmd/tools/gmlparse.y"
                       { dtinsert (G->attrlist, (yyvsp[0].ap)); }
-#line 1761 "gmlparse.c"
+#line 1752 "gmlparse.c"
     break;
 
   case 17:
-#line 304 "../../cmd/tools/gmlparse.y"
+#line 295 "../../cmd/tools/gmlparse.y"
              { N = mkNode(); }
-#line 1767 "gmlparse.c"
+#line 1758 "gmlparse.c"
     break;
 
   case 18:
-#line 304 "../../cmd/tools/gmlparse.y"
+#line 295 "../../cmd/tools/gmlparse.y"
                                              { (yyval.np) = N; N = NULL; }
-#line 1773 "gmlparse.c"
+#line 1764 "gmlparse.c"
     break;
 
   case 21:
-#line 311 "../../cmd/tools/gmlparse.y"
+#line 302 "../../cmd/tools/gmlparse.y"
                        { N->id = (yyvsp[0].str); }
-#line 1779 "gmlparse.c"
+#line 1770 "gmlparse.c"
     break;
 
   case 22:
-#line 312 "../../cmd/tools/gmlparse.y"
+#line 303 "../../cmd/tools/gmlparse.y"
                       { dtinsert (N->attrlist, (yyvsp[0].ap)); }
-#line 1785 "gmlparse.c"
+#line 1776 "gmlparse.c"
     break;
 
   case 23:
-#line 315 "../../cmd/tools/gmlparse.y"
+#line 306 "../../cmd/tools/gmlparse.y"
              { E = mkEdge(); }
-#line 1791 "gmlparse.c"
+#line 1782 "gmlparse.c"
     break;
 
   case 24:
-#line 315 "../../cmd/tools/gmlparse.y"
+#line 306 "../../cmd/tools/gmlparse.y"
                                              { (yyval.ep) = E; E = NULL; }
-#line 1797 "gmlparse.c"
+#line 1788 "gmlparse.c"
     break;
 
   case 27:
-#line 322 "../../cmd/tools/gmlparse.y"
+#line 313 "../../cmd/tools/gmlparse.y"
                            { E->source = (yyvsp[0].str); }
-#line 1803 "gmlparse.c"
+#line 1794 "gmlparse.c"
     break;
 
   case 28:
-#line 323 "../../cmd/tools/gmlparse.y"
+#line 314 "../../cmd/tools/gmlparse.y"
                            { E->target = (yyvsp[0].str); }
-#line 1809 "gmlparse.c"
+#line 1800 "gmlparse.c"
     break;
 
   case 29:
-#line 324 "../../cmd/tools/gmlparse.y"
+#line 315 "../../cmd/tools/gmlparse.y"
                        { dtinsert (E->attrlist, mkAttr(gv_strdup("id"), 0, INTEGER, (yyvsp[0].str), 0)); }
-#line 1815 "gmlparse.c"
+#line 1806 "gmlparse.c"
     break;
 
   case 30:
-#line 325 "../../cmd/tools/gmlparse.y"
+#line 316 "../../cmd/tools/gmlparse.y"
                       { dtinsert (E->attrlist, (yyvsp[0].ap)); }
-#line 1821 "gmlparse.c"
+#line 1812 "gmlparse.c"
     break;
 
   case 31:
-#line 328 "../../cmd/tools/gmlparse.y"
+#line 319 "../../cmd/tools/gmlparse.y"
                 {pushAlist(); }
-#line 1827 "gmlparse.c"
+#line 1818 "gmlparse.c"
     break;
 
   case 32:
-#line 328 "../../cmd/tools/gmlparse.y"
+#line 319 "../../cmd/tools/gmlparse.y"
                                              { (yyval.list) = popAlist(); }
-#line 1833 "gmlparse.c"
+#line 1824 "gmlparse.c"
     break;
 
   case 35:
-#line 335 "../../cmd/tools/gmlparse.y"
+#line 326 "../../cmd/tools/gmlparse.y"
                           { dtinsert (L, (yyvsp[0].ap)); }
-#line 1839 "gmlparse.c"
+#line 1830 "gmlparse.c"
     break;
 
   case 36:
-#line 336 "../../cmd/tools/gmlparse.y"
+#line 327 "../../cmd/tools/gmlparse.y"
                     { dtinsert (L, (yyvsp[0].ap)); }
-#line 1845 "gmlparse.c"
+#line 1836 "gmlparse.c"
     break;
 
   case 37:
-#line 339 "../../cmd/tools/gmlparse.y"
+#line 330 "../../cmd/tools/gmlparse.y"
                          { (yyval.ap) = mkAttr ((yyvsp[-1].str), 0, INTEGER, (yyvsp[0].str), 0); }
-#line 1851 "gmlparse.c"
+#line 1842 "gmlparse.c"
     break;
 
   case 38:
-#line 340 "../../cmd/tools/gmlparse.y"
+#line 331 "../../cmd/tools/gmlparse.y"
                          { (yyval.ap) = mkAttr ((yyvsp[-1].str), 0, REAL, (yyvsp[0].str), 0); }
-#line 1857 "gmlparse.c"
+#line 1848 "gmlparse.c"
     break;
 
   case 39:
-#line 341 "../../cmd/tools/gmlparse.y"
+#line 332 "../../cmd/tools/gmlparse.y"
                          { (yyval.ap) = mkAttr ((yyvsp[-1].str), 0, STRING, (yyvsp[0].str), 0); }
-#line 1863 "gmlparse.c"
+#line 1854 "gmlparse.c"
     break;
 
   case 40:
-#line 342 "../../cmd/tools/gmlparse.y"
+#line 333 "../../cmd/tools/gmlparse.y"
                            { (yyval.ap) = mkAttr ((yyvsp[-1].str), 0, LIST, 0, (yyvsp[0].list)); }
-#line 1869 "gmlparse.c"
+#line 1860 "gmlparse.c"
     break;
 
   case 41:
-#line 343 "../../cmd/tools/gmlparse.y"
+#line 334 "../../cmd/tools/gmlparse.y"
                        { (yyval.ap) = mkAttr (0, XVAL, REAL, (yyvsp[0].str), 0); }
-#line 1875 "gmlparse.c"
+#line 1866 "gmlparse.c"
     break;
 
   case 42:
-#line 344 "../../cmd/tools/gmlparse.y"
+#line 335 "../../cmd/tools/gmlparse.y"
                           { (yyval.ap) = mkAttr (0, XVAL, REAL, (yyvsp[0].str), 0); }
-#line 1881 "gmlparse.c"
+#line 1872 "gmlparse.c"
     break;
 
   case 43:
-#line 345 "../../cmd/tools/gmlparse.y"
+#line 336 "../../cmd/tools/gmlparse.y"
                        { (yyval.ap) = mkAttr (0, YVAL, REAL, (yyvsp[0].str), 0); }
-#line 1887 "gmlparse.c"
+#line 1878 "gmlparse.c"
     break;
 
   case 44:
-#line 346 "../../cmd/tools/gmlparse.y"
+#line 337 "../../cmd/tools/gmlparse.y"
                        { (yyval.ap) = mkAttr (0, WVAL, REAL, (yyvsp[0].str), 0); }
-#line 1893 "gmlparse.c"
+#line 1884 "gmlparse.c"
     break;
 
   case 45:
-#line 347 "../../cmd/tools/gmlparse.y"
+#line 338 "../../cmd/tools/gmlparse.y"
                        { (yyval.ap) = mkAttr (0, HVAL, REAL, (yyvsp[0].str), 0); }
-#line 1899 "gmlparse.c"
+#line 1890 "gmlparse.c"
     break;
 
   case 46:
-#line 348 "../../cmd/tools/gmlparse.y"
+#line 339 "../../cmd/tools/gmlparse.y"
                           { (yyval.ap) = mkAttr (0, LABEL, STRING, (yyvsp[0].str), 0); }
-#line 1905 "gmlparse.c"
+#line 1896 "gmlparse.c"
     break;
 
   case 47:
-#line 349 "../../cmd/tools/gmlparse.y"
+#line 340 "../../cmd/tools/gmlparse.y"
                                { (yyval.ap) = mkAttr (0, GRAPHICS, LIST, 0, (yyvsp[0].list)); }
-#line 1911 "gmlparse.c"
+#line 1902 "gmlparse.c"
     break;
 
   case 48:
-#line 350 "../../cmd/tools/gmlparse.y"
+#line 341 "../../cmd/tools/gmlparse.y"
                                     { (yyval.ap) = mkAttr (0, LABELGRAPHICS, LIST, 0, (yyvsp[0].list)); }
-#line 1917 "gmlparse.c"
+#line 1908 "gmlparse.c"
     break;
 
   case 49:
-#line 351 "../../cmd/tools/gmlparse.y"
+#line 342 "../../cmd/tools/gmlparse.y"
                          { (yyval.ap) = mkAttr (0, TYPE, STRING, (yyvsp[0].str), 0); }
-#line 1923 "gmlparse.c"
+#line 1914 "gmlparse.c"
     break;
 
   case 50:
-#line 352 "../../cmd/tools/gmlparse.y"
+#line 343 "../../cmd/tools/gmlparse.y"
                          { (yyval.ap) = mkAttr (0, FILL, STRING, (yyvsp[0].str), 0); }
-#line 1929 "gmlparse.c"
+#line 1920 "gmlparse.c"
     break;
 
   case 51:
-#line 353 "../../cmd/tools/gmlparse.y"
+#line 344 "../../cmd/tools/gmlparse.y"
                             { (yyval.ap) = mkAttr (0, OUTLINE, STRING, (yyvsp[0].str), 0); }
-#line 1935 "gmlparse.c"
+#line 1926 "gmlparse.c"
     break;
 
   case 52:
-#line 354 "../../cmd/tools/gmlparse.y"
+#line 345 "../../cmd/tools/gmlparse.y"
                                  { (yyval.ap) = mkAttr (0, OUTLINESTYLE, STRING, (yyvsp[0].str), 0); }
-#line 1941 "gmlparse.c"
+#line 1932 "gmlparse.c"
     break;
 
   case 53:
-#line 355 "../../cmd/tools/gmlparse.y"
+#line 346 "../../cmd/tools/gmlparse.y"
                                   { (yyval.ap) = mkAttr (0, OUTLINEWIDTH, INTEGER, (yyvsp[0].str), 0); }
-#line 1947 "gmlparse.c"
+#line 1938 "gmlparse.c"
     break;
 
   case 54:
-#line 356 "../../cmd/tools/gmlparse.y"
+#line 347 "../../cmd/tools/gmlparse.y"
                         { (yyval.ap) = mkAttr (0, WIDTH, REAL, (yyvsp[0].str), 0); }
-#line 1953 "gmlparse.c"
+#line 1944 "gmlparse.c"
     break;
 
   case 55:
-#line 357 "../../cmd/tools/gmlparse.y"
+#line 348 "../../cmd/tools/gmlparse.y"
                            { (yyval.ap) = mkAttr (0, WIDTH, INTEGER, (yyvsp[0].str), 0); }
-#line 1959 "gmlparse.c"
+#line 1950 "gmlparse.c"
     break;
 
   case 56:
-#line 358 "../../cmd/tools/gmlparse.y"
+#line 349 "../../cmd/tools/gmlparse.y"
                           { (yyval.ap) = mkAttr (0, STYLE, STRING, (yyvsp[0].str), 0); }
-#line 1965 "gmlparse.c"
+#line 1956 "gmlparse.c"
     break;
 
   case 57:
-#line 359 "../../cmd/tools/gmlparse.y"
+#line 350 "../../cmd/tools/gmlparse.y"
                             { (yyval.ap) = mkAttr (0, STYLE, LIST, 0, (yyvsp[0].list)); }
-#line 1971 "gmlparse.c"
+#line 1962 "gmlparse.c"
     break;
 
   case 58:
-#line 360 "../../cmd/tools/gmlparse.y"
+#line 351 "../../cmd/tools/gmlparse.y"
                            { (yyval.ap) = mkAttr (0, LINE, LIST, 0, (yyvsp[0].list)); }
-#line 1977 "gmlparse.c"
+#line 1968 "gmlparse.c"
     break;
 
   case 59:
-#line 361 "../../cmd/tools/gmlparse.y"
+#line 352 "../../cmd/tools/gmlparse.y"
                             { (yyval.ap) = mkAttr (0, POINT, LIST, 0, (yyvsp[0].list)); }
-#line 1983 "gmlparse.c"
+#line 1974 "gmlparse.c"
     break;
 
   case 60:
-#line 362 "../../cmd/tools/gmlparse.y"
+#line 353 "../../cmd/tools/gmlparse.y"
                          { (yyval.ap) = mkAttr (0, TEXT, STRING, (yyvsp[0].str), 0); }
-#line 1989 "gmlparse.c"
+#line 1980 "gmlparse.c"
     break;
 
   case 61:
-#line 363 "../../cmd/tools/gmlparse.y"
+#line 354 "../../cmd/tools/gmlparse.y"
                              { (yyval.ap) = mkAttr (0, FONTNAME, STRING, (yyvsp[0].str), 0); }
-#line 1995 "gmlparse.c"
+#line 1986 "gmlparse.c"
     break;
 
   case 62:
-#line 364 "../../cmd/tools/gmlparse.y"
+#line 355 "../../cmd/tools/gmlparse.y"
                               { (yyval.ap) = mkAttr (0, FONTNAME, INTEGER, (yyvsp[0].str), 0); }
-#line 2001 "gmlparse.c"
+#line 1992 "gmlparse.c"
     break;
 
   case 63:
-#line 365 "../../cmd/tools/gmlparse.y"
+#line 356 "../../cmd/tools/gmlparse.y"
                           { (yyval.ap) = mkAttr (0, COLOR, STRING, (yyvsp[0].str), 0); }
-#line 2007 "gmlparse.c"
+#line 1998 "gmlparse.c"
     break;
 
 
-#line 2011 "gmlparse.c"
+#line 2002 "gmlparse.c"
 
       default: break;
     }
@@ -2239,13 +2230,10 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 368 "../../cmd/tools/gmlparse.y"
+#line 359 "../../cmd/tools/gmlparse.y"
 
 
-static void
-free_attr (Dt_t*d, gmlattr* p, Dtdisc_t* ds)
-{
-    (void)d;
+static void free_attr(gmlattr *p, Dtdisc_t *ds) {
     (void)ds;
 
     if (!p) return;
