@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.5.1.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,6 +31,9 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+/* Undocumented macros, especially those whose name start with YY_,
+   are private implementation details.  Do not rely on them.  */
+
 #ifndef YY_GML_GMLPARSE_H_INCLUDED
 # define YY_GML_GMLPARSE_H_INCLUDED
 /* Debug traces.  */
@@ -123,10 +127,9 @@ extern int gmldebug;
 
 /* Value type.  */
 #if ! defined GMLSTYPE && ! defined GMLSTYPE_IS_DECLARED
-
 union GMLSTYPE
 {
-#line 248 "../../cmd/tools/gmlparse.y" /* yacc.c:1909  */
+#line 239 "../../cmd/tools/gmlparse.y"
 
     int i;
     char *str;
@@ -135,9 +138,9 @@ union GMLSTYPE
     gmlattr* ap;
     Dt_t*    list;
 
-#line 139 "gmlparse.h" /* yacc.c:1909  */
-};
+#line 142 "gmlparse.h"
 
+};
 typedef union GMLSTYPE GMLSTYPE;
 # define GMLSTYPE_IS_TRIVIAL 1
 # define GMLSTYPE_IS_DECLARED 1
