@@ -28,6 +28,7 @@
 #include <cgraph/exit.h>
 #include <cgraph/strview.h>
 #include <cgraph/tokenize.h>
+#include <cgraph/unreachable.h>
 #include <common/types.h>
 #include <common/utils.h>
 #include <ctype.h>
@@ -690,6 +691,8 @@ static void initargs(int argc, char **argv)
 		usage(1);
 	    }
 	    break;
+	default:
+	    UNREACHABLE();
 	}
     }
 
@@ -702,11 +705,6 @@ static void initargs(int argc, char **argv)
 	outFile = stdout;
 }
 
-static Agraph_t *gread(FILE * fp)
-{
-    return agread(fp, NULL);
-}
-
 int main(int argc, char **argv)
 {
     Agraph_t *G;
@@ -716,7 +714,7 @@ int main(int argc, char **argv)
 
     rv = 0;
     initargs(argc, argv);
-    newIngraph(&ig, Files, gread);
+    newIngraph(&ig, Files);
 
     while ((G = nextGraph(&ig))) {
 	if (prev) {
