@@ -72,6 +72,9 @@ int agstrclose(Agraph_t * g);
 	/* ref string management */
 void agmarkhtmlstr(char *s);
 
+/// Mask of `Agtag_s.seq` width
+enum { SEQ_MASK = (1 << (sizeof(unsigned) * 8 - 4)) - 1 };
+
 	/* object set management */
 Agnode_t *agfindnode_by_id(Agraph_t * g, IDTYPE id);
 uint64_t agnextseq(Agraph_t * g, int objtype);
@@ -83,10 +86,10 @@ int agdtdelete(Agraph_t * g, Dict_t * dict, void *obj);
 int agdtclose(Agraph_t * g, Dict_t * dict);
 void *agdictobjmem(Dict_t * dict, void * p, size_t size,
 		   Dtdisc_t * disc);
-void agdictobjfree(Dict_t * dict, void * p, Dtdisc_t * disc);
+void agdictobjfree(void *p, Dtdisc_t *disc);
 
 	/* name-value pair operations */
-CGHDR_API Agdatadict_t *agdatadict(Agraph_t * g, int cflag);
+CGHDR_API Agdatadict_t *agdatadict(Agraph_t *g, bool cflag);
 CGHDR_API Agattr_t *agattrrec(void *obj);
 
 void agraphattr_init(Agraph_t * g);
@@ -104,8 +107,8 @@ void aglexeof(void);
 void aglexbad(void);
 
 	/* ID management */
-int agmapnametoid(Agraph_t * g, int objtype, char *str,
-          IDTYPE *result, int createflag);
+int agmapnametoid(Agraph_t *g, int objtype, char *str, IDTYPE *result,
+                  bool createflag);
 int agallocid(Agraph_t * g, int objtype, IDTYPE request);
 void agfreeid(Agraph_t * g, int objtype, IDTYPE id);
 char *agprintid(Agobj_t * obj);
@@ -129,9 +132,6 @@ void agmethod_init(Agraph_t * g, void *obj);
 void agmethod_upd(Agraph_t * g, void *obj, Agsym_t * sym);
 void agmethod_delete(Agraph_t * g, void *obj);
 
-typedef enum { CB_INITIALIZE, CB_UPDATE, CB_DELETION, } cb_t;
-void agrecord_callback(Agraph_t * g, Agobj_t * obj, cb_t kind,
-		       Agsym_t * optsym);
 void aginitcb(Agraph_t * g, void *obj, Agcbstack_t * disc);
 void agupdcb(Agraph_t * g, void *obj, Agsym_t * sym, Agcbstack_t * disc);
 void agdelcb(Agraph_t * g, void *obj, Agcbstack_t * disc);
