@@ -43,13 +43,11 @@ int agrename(Agobj_t * obj, char *newname)
 	old_id = AGID(obj);
 	g = agraphof(obj);
 	/* can we reserve the id corresponding to newname? */
-	if (agmapnametoid(agroot(g), AGTYPE(obj), newname,
-			  &new_id, FALSE) == 0)
+	if (agmapnametoid(agroot(g), AGTYPE(obj), newname, &new_id, false) == 0)
 	    return FAILURE;
 	if (new_id == old_id)
 	    return SUCCESS;
-	if (agmapnametoid(agroot(g), AGTYPE(obj), newname,
-			  &new_id, TRUE) == 0)
+	if (agmapnametoid(agroot(g), AGTYPE(obj), newname, &new_id, true) == 0)
 	    return FAILURE;
         /* obj* is unchanged, so no need to re agregister() */
 	if (agparent(g) && agidsubg(agparent(g), new_id, 0))
@@ -59,8 +57,6 @@ int agrename(Agobj_t * obj, char *newname)
 	break;
     case AGNODE:
 	return agrelabel_node((Agnode_t *) obj, newname);
-	agrename(obj, newname);
-	break;
     case AGINEDGE:
     case AGOUTEDGE:
 	return FAILURE;
@@ -76,10 +72,7 @@ int agrename(Agobj_t * obj, char *newname)
 
 void agmethod_init(Agraph_t * g, void *obj)
 {
-    if (g->clos->callbacks_enabled)
-	aginitcb(g, obj, g->clos->cb);
-    else
-	agrecord_callback(g, obj, CB_INITIALIZE, NULL);
+  aginitcb(g, obj, g->clos->cb);
 }
 
 void aginitcb(Agraph_t * g, void *obj, Agcbstack_t * cbstack)
@@ -107,10 +100,7 @@ void aginitcb(Agraph_t * g, void *obj, Agcbstack_t * cbstack)
 
 void agmethod_upd(Agraph_t * g, void *obj, Agsym_t * sym)
 {
-    if (g->clos->callbacks_enabled)
-	agupdcb(g, obj, sym, g->clos->cb);
-    else
-	agrecord_callback(g, obj, CB_UPDATE, sym);
+  agupdcb(g, obj, sym, g->clos->cb);
 }
 
 void agupdcb(Agraph_t * g, void *obj, Agsym_t * sym, Agcbstack_t * cbstack)
@@ -138,10 +128,7 @@ void agupdcb(Agraph_t * g, void *obj, Agsym_t * sym, Agcbstack_t * cbstack)
 
 void agmethod_delete(Agraph_t * g, void *obj)
 {
-    if (g->clos->callbacks_enabled)
-	agdelcb(g, obj, g->clos->cb);
-    else
-	agrecord_callback(g, obj, CB_DELETION, NULL);
+  agdelcb(g, obj, g->clos->cb);
 }
 
 void agdelcb(Agraph_t * g, void *obj, Agcbstack_t * cbstack)
