@@ -33,9 +33,7 @@ static Dtdisc_t Refstrdisc = {
     NULL,
     agdictobjfree,
     NULL,
-    NULL,
     agdictobjmem,
-    NULL
 };
 
 static Dict_t *Refdict_default;
@@ -180,12 +178,8 @@ void agmarkhtmlstr(char *s)
 }
 
 #ifdef DEBUG
-static int refstrprint(Dict_t * dict, void *ptr, void *user)
-{
-    refstr_t *r;
-
-    (void)dict;
-    r = ptr;
+static int refstrprint(void *ptr, void *user) {
+    refstr_t *r = ptr;
     (void)user;
     fprintf(stderr, "%s\n", r->s);
     return 0;
