@@ -8,6 +8,7 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include <assert.h>
 #include <limits.h>
 #include <stdbool.h>
 #include <stddef.h>
@@ -50,6 +51,43 @@ static bool is_id_char(char c) {
   return isalnum(c) || c == '.' || c == '-' || !isascii(c);
 }
 
+// is the prefix of this string a recognized Graphviz escape sequence?
+// https://graphviz.org/docs/attr-types/escString/
+static bool is_escape(const char *str) {
+  assert(str != NULL);
+
+  if (*str != '\\')
+    return false;
+
+  if (str[1] == 'E')
+    return true;
+  if (str[1] == 'G')
+    return true;
+  if (str[1] == 'H')
+    return true;
+  if (str[1] == 'L')
+    return true;
+  if (str[1] == 'N')
+    return true;
+  if (str[1] == 'T')
+    return true;
+
+  if (str[1] == 'l')
+    return true;
+  if (str[1] == 'n')
+    return true;
+  if (str[1] == 'r')
+    return true;
+
+  if (str[1] == '\\')
+    return true;
+
+  if (str[1] == '"')
+    return true;
+
+  return false;
+}
+
 /* _agstrcanon:
  * Canonicalize ordinary strings. 
  * Assumes buf is large enough to hold output.
@@ -60,6 +98,7 @@ static char *_agstrcanon(char *arg, char *buf)
     char uc;
     int cnt = 0, dotcnt = 0;
     bool needs_quotes = false;
+    bool part_of_escape = false;
     bool maybe_num;
     bool backslash_pending = false;
     static const char *tokenlist[]	/* must agree with scan.l */
@@ -76,11 +115,13 @@ static char *_agstrcanon(char *arg, char *buf)
     uc = *s++;
     maybe_num = isdigit(uc) != 0 || uc == '.' || uc == '-';
     while (uc) {
-	if (uc == '\"') {
+	if (uc == '\"' && !part_of_escape) {
 	    *p++ = '\\';
 	    needs_quotes = true;
-	} 
-	else if (maybe_num) {
+	} else if (!part_of_escape && is_escape(&s[-1])) {
+	    needs_quotes = true;
+	    part_of_escape = true;
+	} else if (maybe_num) {
 	    if (uc == '-') {
 		if (cnt) {
 		    maybe_num = false;
@@ -97,9 +138,12 @@ static char *_agstrcanon(char *arg, char *buf)
 		maybe_num = false;
 		needs_quotes = true;
 	    }
+	    part_of_escape = false;
 	}
-	else if (!(isalnum(uc) || uc == '_' || !isascii(uc)))
+	else if (!(isalnum(uc) || uc == '_' || !isascii(uc))) {
 	    needs_quotes = true;
+	    part_of_escape = false;
+	}
 	*p++ = uc;
 	uc = *s++;
 	cnt++;
@@ -286,7 +330,7 @@ static int write_dict(Agraph_t * g, iochan_t * ofile, char *name,
 static int write_dicts(Agraph_t * g, iochan_t * ofile, int top)
 {
     Agdatadict_t *def;
-    if ((def = agdatadict(g, FALSE))) {
+    if ((def = agdatadict(g, false))) {
 	CHKRV(write_dict(g, ofile, "graph", def->dict.g, top));
 	CHKRV(write_dict(g, ofile, "node", def->dict.n, top));
 	CHKRV(write_dict(g, ofile, "edge", def->dict.e, top));
@@ -366,7 +410,7 @@ static bool irrelevant_subgraph(Agraph_t * g)
 		&& strcmp(sdata->str[i], pdata->str[i]))
 		return false;
     }
-    dd = agdatadict(g, FALSE);
+    dd = agdatadict(g, false);
     if (!dd)
 	return true;
     if (dtsize(dd->dict.n) > 0 || dtsize(dd->dict.e) > 0)
@@ -381,7 +425,7 @@ static bool node_in_subg(Agraph_t * g, Agnode_t * n)
     for (subg = agfstsubg(g); subg; subg = agnxtsubg(subg)) {
 	if (irrelevant_subgraph(subg))
 	    continue;
-	if (agsubnode(subg, n, FALSE))
+	if (agsubnode(subg, n, 0))
 	    return true;
     }
     return false;
@@ -501,7 +545,7 @@ static int write_nondefault_attrs(void *obj, iochan_t * ofile,
 	CHKRV(ioput(g, ofile, "]"));
 	Level--;
     }
-    AGATTRWF((Agobj_t *) obj) = TRUE;
+    AGATTRWF(obj) = TRUE;
     return 0;
 }
 
@@ -591,7 +635,7 @@ static int write_edge_test(Agraph_t * g, Agedge_t * e)
     for (subg = agfstsubg(g); subg; subg = agnxtsubg(subg)) {
 	if (irrelevant_subgraph(subg))
 	    continue;
-	if (agsubedge(subg, e, FALSE))
+	if (agsubedge(subg, e, 0))
 	    return FALSE;
     }
     return TRUE;
@@ -626,7 +670,7 @@ static int write_body(Agraph_t * g, iochan_t * ofile)
     Agdatadict_t *dd;
 
     CHKRV(write_subgs(g, ofile));
-    dd = agdatadict(g, FALSE);
+    dd = agdatadict(g, false);
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	if (write_node_test(g, n, AGSEQ(n)))
 	    CHKRV(write_node(n, ofile, dd ? dd->dict.n : 0));
