@@ -8,7 +8,7 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-
+#include <cgraph/alloc.h>
 #include <common/render.h>
 #include <common/pointset.h>
 
@@ -19,16 +19,12 @@ typedef struct {
 
 static pair *mkPair(point p)
 {
-    pair *pp;
-
-    pp = NEW(pair);
+    pair *pp = gv_alloc(sizeof(pair));
     pp->id = p;
     return pp;
 }
 
-static void freePair(Dt_t * d, pair* pp, Dtdisc_t * disc)
-{
-    (void)d;
+static void freePair(pair *pp, Dtdisc_t *disc) {
     (void)disc;
 
     free (pp);
@@ -59,8 +55,6 @@ static Dtdisc_t intPairDisc = {
     (Dtfree_f) freePair,
     (Dtcompar_f) cmppair,
     0,
-    0,
-    0
 };
 
 PointSet *newPS(void)
@@ -140,26 +134,20 @@ typedef struct {
     mpair *flist;
 } MPairDisc;
 
-static mpair *mkMPair(Dt_t * d, mpair * obj, MPairDisc * disc)
-{
-    (void)d;
-
+static mpair *mkMPair(mpair *obj, MPairDisc *disc) {
     mpair *ap;
 
     if (disc->flist) {
 	ap = disc->flist;
 	disc->flist = (mpair *) (ap->link.right);
     } else
-	ap = GNEW(mpair);
+	ap = gv_alloc(sizeof(mpair));
     ap->id = obj->id;
     ap->v = obj->v;
     return ap;
 }
 
-static void freeMPair(Dt_t * d, mpair * ap, MPairDisc * disc)
-{
-    (void)d;
-
+static void freeMPair(mpair *ap, MPairDisc *disc) {
     ap->link.right = (Dtlink_t *) (disc->flist);
     disc->flist = ap;
 }
@@ -172,13 +160,11 @@ static Dtdisc_t intMPairDisc = {
     (Dtfree_f) freeMPair,
     (Dtcompar_f) cmppair,
     0,
-    0,
-    0
 };
 
 PointMap *newPM(void)
 {
-    MPairDisc *dp = GNEW(MPairDisc);
+    MPairDisc *dp = gv_alloc(sizeof(MPairDisc));
 
     dp->disc = intMPairDisc;
     dp->flist = 0;
