@@ -106,9 +106,7 @@ pointf textspan_size(GVC_t *gvc, textspan_t * span)
     return span->size;
 }
 
-static void* textfont_makef(Dt_t* dt, void* obj, Dtdisc_t* disc)
-{
-    (void)dt;
+static void *textfont_makef(void *obj, Dtdisc_t *disc) {
     (void)disc;
 
     textfont_t *f1 = obj;
@@ -126,9 +124,7 @@ static void* textfont_makef(Dt_t* dt, void* obj, Dtdisc_t* disc)
     return f2;
 }
 
-static void textfont_freef(Dt_t* dt, void* obj, Dtdisc_t* disc)
-{
-    (void)dt;
+static void textfont_freef(void *obj, Dtdisc_t *disc) {
     (void)disc;
 
     textfont_t *f = obj;
@@ -165,11 +161,9 @@ static int textfont_comparf (Dt_t* dt, void* key1, void* key2, Dtdisc_t* disc)
     return 0;
 }
 
-Dt_t * textfont_dict_open(GVC_t *gvc)
-{
-    DTDISC(&(gvc->textfont_disc),0,sizeof(textfont_t),-1,textfont_makef,textfont_freef,textfont_comparf,NULL,NULL,NULL);
+void textfont_dict_open(GVC_t *gvc) {
+    DTDISC(&gvc->textfont_disc, 0, sizeof(textfont_t), -1, textfont_makef, textfont_freef, textfont_comparf, NULL);
     gvc->textfont_dt = dtopen(&(gvc->textfont_disc), Dtoset);
-    return gvc->textfont_dt;
 }
 
 void textfont_dict_close(GVC_t *gvc)
