@@ -247,41 +247,6 @@ Agraphinfo_t* GD_info(graph_t * g) { return ((Agraphinfo_t*)AGDATA(g));}
 Agnodeinfo_t* ND_info(node_t * n) { return ((Agnodeinfo_t*)AGDATA(n));}
 #endif
 
-#if !defined(_WIN32)
-#include	<pwd.h>
-
-#endif
-
-/* Fgets:
- * Read a complete line.
- * Return pointer to line,
- * or 0 on EOF
- */
-char *Fgets(FILE * fp)
-{
-    static size_t bsize = 0;
-    static char *buf;
-    char *lp;
-    size_t len;
-
-    len = 0;
-    do {
-	if (bsize - len < BUFSIZ) {
-	    bsize += BUFSIZ;
-	    buf = grealloc(buf, bsize);
-	}
-	lp = fgets(buf + len, (int)(bsize - len), fp);
-	if (lp == 0)
-	    break;
-	len += strlen(lp);	/* since lp != NULL, len > 0 */
-    } while (buf[len - 1] != '\n');
-
-    if (len > 0)
-	return buf;
-    else
-	return 0;
-}
-
 /* safefile:
  * Check to make sure it is okay to read in files.
  * It returns NULL if the filename is trivial.
@@ -519,7 +484,7 @@ void gvToggle(int s)
 #endif
 }
 
-int test_toggle()
+int test_toggle(void)
 {
     return Tflag;
 }
@@ -898,9 +863,7 @@ static int cmpItem(Dt_t * d, void *p1[], void *p2[], Dtdisc_t * disc)
 
 /* newItem:
  */
-static void *newItem(Dt_t * d, item * objp, Dtdisc_t * disc)
-{
-    (void)d;
+static void *newItem(item *objp, Dtdisc_t *disc) {
     item *newp = gv_alloc(sizeof(item));
 
     (void)disc;
@@ -914,9 +877,7 @@ static void *newItem(Dt_t * d, item * objp, Dtdisc_t * disc)
 
 /* freeItem:
  */
-static void freeItem(Dt_t * d, item * obj, Dtdisc_t * disc)
-{
-    (void)d;
+static void freeItem(item *obj, Dtdisc_t *disc) {
     (void)disc;
     free(obj);
 }
@@ -1748,9 +1709,7 @@ typedef struct {
     Agraph_t* clp;
 } clust_t;
 
-static void free_clust (Dt_t* dt, clust_t* clp, Dtdisc_t* disc)
-{
-    (void)dt;
+static void free_clust(clust_t *clp, Dtdisc_t *disc) {
     (void)disc;
     free(clp);
 }
