@@ -23,21 +23,16 @@ extern "C" {
 #define _EXLIB_H
 
 #include <ast/ast.h>
-#include <sfio/sfio_t.h>
-
-#define sfstrseek(f,p,m) \
-    ( \
-        (((p) < 0 || (p) > (f)->size) ? (char*)0 : \
-         (char*)((f)->next = (f)->data+(p)) ) \
-    )
-
+#include <cgraph/agxbuf.h>
+#include <sfio/sfio.h>
+#include <stdio.h>
 
 typedef struct Exinput_s		/* input stack			*/
 {
 	struct Exinput_s*next;		/* next in stack		*/
 	int		close;		/* close fp on pop		*/
 	char*		file;		/* previous file		*/
-	Sfio_t*		fp;		/* expression file pointer	*/
+	FILE*		fp;		/* expression file pointer	*/
 	int		line;		/* previous line		*/
 	int		nesting;	/* expression nesting level	*/
 	int		peek;		/* 1 char peek			*/
@@ -111,7 +106,7 @@ typedef struct Print_s			/* compiled printf arg node	*/
 	Exdisc_t*	disc;		/* user discipline		*/ \
 	Exinput_t*	input;		/* input stack			*/ \
 	Expr_t*		program;	/* previous program on stack	*/ \
-	Sfio_t*		tmp;		/* tmp string buffer		*/ \
+	agxbuf		tmp;		/* tmp string buffer		*/ \
 	Extype_t	loopret;	/* return value			*/ \
 	Exid_t		main;		/* main procedure		*/ \
 	char		line[512];	/* last few input tokens	*/ \
@@ -120,14 +115,13 @@ typedef struct Print_s			/* compiled printf arg node	*/
 	int		errors;		/* fatal error count		*/ \
 	int		formals;	/* parsing formal args		*/ \
 	int		linewrap;	/* linep wrapped around line[]	*/ \
-	int		loopcount;	/* break|continue|return count	*/ \
+	long long loopcount; /* break|continue|return count	*/ \
 	int		loopop;		/* break|continue|return op	*/ \
 	int		nesting;	/* exstatement() nesting	*/
 
 #include <expr/expr.h>
 #include <ctype.h>
 #include <ast/error.h>
-#include <ast/sfstr.h>
 
 #define id_string	(&exbuiltin[0])
 
