@@ -1,6 +1,3 @@
-/* $Id: extype.c,v 1.4 2011/01/25 16:30:48 ellson Exp $ $Revision: 1.4 $ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 /*
@@ -18,7 +15,7 @@
  * expression library C program generator
  */
 
-#include "exlib.h"
+#include <expr/exlib.h>
 
 #define str(s)		# s
 #define xstr(s)		str(s)
@@ -27,15 +24,15 @@
  * return C type name for type
  */
 
-char *extype(int type)
-{
-    switch (type) {
-    case FLOATING:
-	return "double";
-    case STRING:
-	return "char*";
-    case UNSIGNED:
-	return xstr(unsigned _ast_intmax_t);
-    }
-    return xstr(_ast_intmax_t);
+char *extype(long int type) {
+	switch (type)
+	{
+	case FLOATING:
+		return "double";
+	case STRING:
+		return "char*";
+	case UNSIGNED:
+		return xstr(uintmax_t);
+	}
+	return xstr(intmax_t);
 }
