@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,20 +5,20 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#pragma once
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#ifndef COMPILE_H
-#define COMPILE_H
-
-#include <sfio.h>
+#include <sfio/sfio.h>
 #include <parse.h>
 #include <gprstate.h>
-#include <expr.h>
+#include <expr/expr.h>
+#include <stdio.h>
 
     typedef struct {
 	Exnode_t *guard;
@@ -32,21 +29,17 @@ extern "C" {
 
     typedef struct {
 	Agrec_t h;
-	/* Extype_t xu; */
 	Extype_t iu;
 	Agedge_t* ine;
     } nval_t;
 
     typedef struct {
 	Agrec_t h;
-	/* Extype_t xu; */
-	/* Extype_t iu; */
 	char lock;
     } gval_t;
 
     typedef struct {
 	Agrec_t h;
-	/* Extype_t xu; */
     } uval_t;
 
 #define OBJ(p) ((Agobj_t*)p)
@@ -89,14 +82,12 @@ extern "C" {
     extern void freeCompileProg (comp_prog *p);
     extern int usesGraph(comp_prog *);
     extern int walksGraph(comp_block *);
-    extern Agraph_t *readG(Sfio_t * fp);
+    extern Agraph_t *readG(FILE *fp);
     extern Agraph_t *openG(char *name, Agdesc_t);
     extern Agraph_t *openSubg(Agraph_t * g, char *name);
     extern Agnode_t *openNode(Agraph_t * g, char *name);
     extern Agedge_t *openEdge(Agraph_t* g, Agnode_t * t, Agnode_t * h, char *key);
 
-#endif
-
 #ifdef __cplusplus
 }
 #endif
