@@ -30,10 +30,10 @@
 #include <gvpr/queue.h>
 #include <gvpr/gvpr.h>
 #include <gvpr/actions.h>
-#include <ast/sfstr.h>
 #include <ast/error.h>
 #include <stdbool.h>
 #include <stddef.h>
+#include <stdio.h>
 #include <string.h>
 #include <ctype.h>
 #include <setjmp.h>
@@ -64,7 +64,7 @@ If no files are specified, stdin is used\n";
 
 typedef struct {
     char *cmdName;              /* command name */
-    Sfio_t *outFile;		/* output stream; stdout default */
+    FILE *outFile;		/* output stream; stdout default */
     char *program;              /* program source */
     int useFile;		/* true if program comes from a file */
     int compflags;
@@ -76,11 +76,8 @@ typedef struct {
     int verbose;
 } options;
 
-static Sfio_t *openOut(char *name)
-{
-    Sfio_t *outs;
-
-    outs = sfopen(name, "w");
+static FILE *openOut(char *name) {
+    FILE *outs = fopen(name, "w");
     if (outs == 0) {
 	error(ERROR_ERROR, "could not open %s for writing", name);
     }
@@ -190,10 +187,9 @@ static int parseArgs(char *s, int argc, char ***argv)
 static char*
 concat (char* pfx, char* sfx)
 {
-    char *sp = gv_alloc(strlen(pfx) + strlen(sfx) + 1);
-    strcpy(sp, pfx);
-    strcat(sp, sfx);
-    return sp;
+  agxbuf sp = {0};
+  agxbprint(&sp, "%s%s", pfx, sfx);
+  return agxbdisown(&sp);
 }
 
 /* resolve:
@@ -204,8 +200,7 @@ concat (char* pfx, char* sfx)
  * 
  * FIX - use pathinclude/pathfind
  */
-static char *resolve(char *arg, int Verbose)
-{
+static char *resolve(char *arg, int verbose) {
     char *path;
     char *s;
     char *cp;
@@ -230,7 +225,7 @@ static char *resolve(char *arg, int Verbose)
     }
     else
 	path = DFLT_GVPRPATH;
-    if (Verbose)
+    if (verbose)
 	fprintf (stderr, "PATH: %s\n", path);
     agxbuf fp = {0};
 
@@ -261,7 +256,7 @@ static char *resolve(char *arg, int Verbose)
 
     agxbfree(&fp);
     free(pathp);
-    if (Verbose)
+    if (verbose)
 	fprintf (stderr, "file %s resolved to %s\n", arg, fname);
     return fname;
 }
@@ -360,8 +355,8 @@ doFlags(char* arg, int argi, int argc, char** argv, options* opts)
 }
 
 static void freeOpts(options opts) {
-    if (opts.outFile != sfstdout)
-	sfclose(opts.outFile);
+    if (opts.outFile != NULL && opts.outFile != stdout)
+	fclose(opts.outFile);
     free(opts.inFiles);
     if (opts.useFile)
 	free(opts.program);
@@ -427,7 +422,7 @@ static options scanArgs(int argc, char **argv) {
 	opts.inFiles = input_filenames;
 
     if (!opts.outFile)
-	opts.outFile = sfstdout;
+	opts.outFile = stdout;
 
   opts_done:
     if (opts.state <= 0) {
@@ -456,7 +451,7 @@ static Agobj_t* evalEdge(Gpr_t * state, Expr_t* prog, comp_block * xprog, Agedge
 	    if (cs->action)
 		exeval(prog, cs->action, state);
 	    else
-		agsubedge(state->target, e, TRUE);
+		agsubedge(state->target, e, 1);
 	}
     }
     return state->curobj;
@@ -479,7 +474,7 @@ static Agobj_t* evalNode(Gpr_t * state, Expr_t* prog, comp_block * xprog, Agnode
 	    if (cs->action)
 		exeval(prog, cs->action, state);
 	    else
-		agsubnode(state->target, n, TRUE);
+		agsubnode(state->target, n, 1);
 	}
     }
     return (state->curobj);
@@ -845,34 +840,11 @@ static void chkClose(Agraph_t * g)
 	agclose(g);
 }
 
-static void *ing_open(char *f)
-{
-    return sfopen(f, "r");
-}
-
 static Agraph_t *ing_read(void *fp)
 {
     return readG(fp);
 }
 
-static int ing_close(void *fp)
-{
-    return sfclose(fp);
-}
-
-static ingdisc ingDisc = { ing_open, ing_read, ing_close, 0 };
-
-static void
-setDisc (Sfio_t* sp, Sfdisc_t* dp, gvprwr fn)
-{
-    dp->readf = 0;
-    dp->writef = (Sfwrite_f)fn;
-    dp->seekf = 0;
-    dp->exceptf = 0;
-    dp->disc = 0;
-    dp = sfdisc (sp, dp);
-}
-
 static jmp_buf jbuf;
 
 /* gvexitf:
@@ -930,18 +902,11 @@ typedef struct {
  */
 static int gvpr_core(int argc, char *argv[], gvpropts *uopts,
                      gvpr_state_t *gs) {
-    Sfdisc_t errdisc;
-    Sfdisc_t outdisc;
     gpr_info info;
     int rv = 0;
     int cleanup, i, incoreGraphs;
 
     setErrorErrors (0);
-    ingDisc.dflt = sfstdin;
-    if (uopts) {
-	if (uopts->out) setDisc (sfstdout, &outdisc, uopts->out);
-	if (uopts->err) setDisc (sfstderr, &errdisc, uopts->err);
-    }
 
     gs->opts = scanArgs(argc, argv);
     if (gs->opts.state <= 0) {
@@ -1005,9 +970,9 @@ static int gvpr_core(int argc, char *argv[], gvpropts *uopts,
     /* if program is not null */
     if (usesGraph(gs->xprog)) {
 	if (uopts && uopts->ingraphs)
-	    gs->ing = newIngGraphs(0, uopts->ingraphs, &ingDisc);
+	    gs->ing = newIngGraphs(0, uopts->ingraphs, ing_read);
 	else
-	    gs->ing = newIng(0, gs->opts.inFiles, &ingDisc);
+	    gs->ing = newIng(0, gs->opts.inFiles, ing_read);
 	
 	if (gs->opts.verbose) gvstart_timer ();
 	Agraph_t* nextg = NULL;
@@ -1056,7 +1021,7 @@ static int gvpr_core(int argc, char *argv[], gvpropts *uopts,
 		if (uopts && (uopts->flags & GV_USE_OUTGRAPH))
 		    addOutputGraph(gs->state, uopts);
 		else
-		    sfioWrite(gs->state->outgraph, gs->opts.outFile, gs->state->dfltIO);
+		    sfioWrite(gs->state->outgraph, gs->opts.outFile);
 	    }
 
 	    if (!incoreGraphs)
@@ -1090,7 +1055,7 @@ int gvpr(int argc, char *argv[], gvpropts *uopts) {
   gvpr_state_t gvpr_state = {0};
 
   // initialize opts to something that makes freeOpts() a no-op if we fail early
-  gvpr_state.opts.outFile = sfstdout;
+  gvpr_state.opts.outFile = stdout;
 
   int rv = gvpr_core(argc, argv, uopts, &gvpr_state);
 
@@ -1103,15 +1068,6 @@ int gvpr(int argc, char *argv[], gvpropts *uopts) {
   }
   freeOpts(gvpr_state.opts);
 
-  if (uopts != NULL) {
-    if (uopts->out != NULL) {
-      sfdisc(sfstdout, 0);
-    }
-    if (uopts->err != NULL) {
-      sfdisc(sfstderr, 0);
-    }
-  }
-
   return rv;
 }
 
