@@ -13,17 +13,11 @@
  * Written by Emden Gansner
  */
 
+#include <cgraph/cgraph.h>
+#include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
 
-#define FREE_STATE 1
-
-typedef struct {
-    char *dummy;
-} Agraph_t;
-
-extern void agsetfile(char *);
-
 #include <ingraphs/ingraphs.h>
 
 /* nextFile:
@@ -37,14 +31,14 @@ static void nextFile(ingraph_state * sp)
 
     if (sp->u.Files == NULL) {
 	if (sp->ctr++ == 0) {
-	    rv = sp->fns->dflt;
+	    rv = stdin;
 	}
     } else {
 	while ((fname = sp->u.Files[sp->ctr++])) {
 	    if (*fname == '-') {
-		rv = sp->fns->dflt;
+		rv = stdin;
 		break;
-	    } else if ((rv = sp->fns->openf(fname)) != 0)
+	    } else if ((rv = fopen(fname, "r")) != 0)
 		break;
 	    else {
 		fprintf(stderr, "Can't open %s\n", sp->u.Files[sp->ctr - 1]);
@@ -66,7 +60,7 @@ Agraph_t *nextGraph(ingraph_state * sp)
     Agraph_t *g;
 
     if (sp->ingraphs) {
-	g = (Agraph_t*)(sp->u.Graphs[sp->ctr]);
+	g = sp->u.Graphs[sp->ctr];
 	if (g) sp->ctr++;
 	return g;
     }
@@ -75,10 +69,10 @@ Agraph_t *nextGraph(ingraph_state * sp)
     g = NULL;
 
     while (sp->fp != NULL) {
-	if ((g = sp->fns->readf(sp->fp)) != 0)
+	if ((g = sp->readf(sp->fp)) != 0)
 	    break;
 	if (sp->u.Files)	/* Only close if not using stdin */
-	    sp->fns->closef(sp->fp);
+	    (void)fclose(sp->fp);
 	nextFile(sp);
     }
     return g;
@@ -89,7 +83,7 @@ Agraph_t *nextGraph(ingraph_state * sp)
  * assume user is supplying memory.
  */
 static ingraph_state*
-new_ing(ingraph_state * sp, char **files, Agraph_t** graphs, ingdisc * disc)
+new_ing(ingraph_state * sp, char **files, Agraph_t** graphs, Agraph_t *(*readf)(void*))
 {
     if (!sp) {
 	sp = malloc(sizeof(ingraph_state));
@@ -97,9 +91,9 @@ new_ing(ingraph_state * sp, char **files, Agraph_t** graphs, ingdisc * disc)
 	    fprintf(stderr, "ingraphs: out of memory\n");
 	    return 0;
 	}
-	sp->heap = 1;
+	sp->heap = true;
     } else
-	sp->heap = 0;
+	sp->heap = false;
     if (graphs) {
 	sp->ingraphs = 1;
 	sp->u.Graphs = graphs;
@@ -111,69 +105,40 @@ new_ing(ingraph_state * sp, char **files, Agraph_t** graphs, ingdisc * disc)
     sp->ctr = 0;
     sp->errors = 0;
     sp->fp = NULL;
-    sp->fns = malloc(sizeof(ingdisc));
-    if (!sp->fns) {
-	fprintf(stderr, "ingraphs: out of memory\n");
+    if (!readf) {
 	if (sp->heap)
 	    free(sp);
+	fprintf(stderr, "ingraphs: NULL read function\n");
 	return 0;
     }
-    if (!disc->openf || !disc->readf || !disc->closef || !disc->dflt) {
-	free(sp->fns);
-	if (sp->heap)
-	    free(sp);
-	fprintf(stderr, "ingraphs: NULL field in ingdisc argument\n");
-	return 0;
-    }
-    *sp->fns = *disc;
+    sp->readf = readf;
     return sp;
 }
 
-ingraph_state*
-newIng(ingraph_state * sp, char **files, ingdisc * disc)
-{
-    return new_ing(sp, files, 0, disc);
+ingraph_state *newIng(ingraph_state *sp, char **files,
+                      Agraph_t *(*readf)(void *)) {
+  return new_ing(sp, files, 0, readf);
 }
 
 /* newIngGraphs:
  * Create new ingraph state using supplied graphs. If sp is non-NULL, we
  * assume user is supplying memory.
  */
-ingraph_state*
-newIngGraphs(ingraph_state * sp , Agraph_t** graphs, ingdisc *disc)
-{
-    return new_ing(sp, 0, graphs, disc);
+ingraph_state *newIngGraphs(ingraph_state *sp, Agraph_t **graphs,
+                            Agraph_t *(*readf)(void *)) {
+  return new_ing(sp, 0, graphs, readf);
 }
 
-static void *dflt_open(char *f)
-{
-    return fopen(f, "r");
+static Agraph_t *dflt_read(void *fp) {
+  return agread(fp, NULL);
 }
 
-static int dflt_close(void *fp)
-{
-    return fclose((FILE *) fp);
-}
-
-typedef Agraph_t *(*xopengfn) (void *);
-
-static ingdisc dflt_disc = { dflt_open, 0, dflt_close, 0 };
-
 /* newIngraph:
  * At present, we require opf to be non-NULL. In
  * theory, we could assume a function agread(FILE*,void*)
  */
-ingraph_state *newIngraph(ingraph_state * sp, char **files, opengfn opf)
-{
-    if (!dflt_disc.dflt)
-	dflt_disc.dflt = stdin;
-    if (opf)
-	dflt_disc.readf = (xopengfn) opf;
-    else {
-	fprintf(stderr, "ingraphs: NULL graph reader\n");
-	return 0;
-    }
-    return newIng(sp, files, &dflt_disc);
+ingraph_state *newIngraph(ingraph_state * sp, char **files) {
+  return newIng(sp, files, dflt_read);
 }
 
 /* closeIngraph:
@@ -183,8 +148,7 @@ ingraph_state *newIngraph(ingraph_state * sp, char **files, opengfn opf)
 void closeIngraph(ingraph_state * sp)
 {
     if (!sp->ingraphs && sp->u.Files && sp->fp)
-	sp->fns->closef(sp->fp);
-    free(sp->fns);
+	(void)fclose(sp->fp);
     if (sp->heap)
 	free(sp);
 }
@@ -211,5 +175,3 @@ char *fileName(ingraph_state * sp)
     } else
 	return "<stdin>";
 }
-
-#include "config.h"
