@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,18 +5,17 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#pragma once
+
+#include <stddef.h>
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-
-
-#ifndef GEOMETRY_H
-#define GEOMETRY_H
-
 #ifdef HAVE_POINTF_S
     typedef pointf Point;
 #else
@@ -33,7 +29,7 @@ extern "C" {
     extern double xmin, xmax, ymin, ymax;	/* extreme x,y values of sites */
     extern double deltax, deltay;	/* xmax - xmin, ymax - ymin */
 
-    extern int nsites;		/* Number of sites */
+    extern size_t nsites; // Number of sites
     extern int sqrt_nsites;
 
     extern void geominit(void);
@@ -44,9 +40,6 @@ extern "C" {
     extern int leftOf(Point a, Point b, Point c);
     extern int intersection(Point a, Point b, Point c, Point d, Point * p);
 
-#endif
-
-
 #ifdef __cplusplus
 }
 #endif
