@@ -237,7 +237,7 @@ convertSPtoRoute (sgraph* g, snode* fst, snode* lst)
 	next = N_DAD(next);
     }
 
-    rte.segs = realloc (rte.segs, rte.n*sizeof(segment));
+    rte.segs = gv_recalloc(rte.segs, sz - 2, rte.n, sizeof(segment));
     for (size_t i=0; i<rte.n; i++) {
 	if (i > 0)
 	    rte.segs[i].prev = rte.segs + (i-1);
@@ -254,10 +254,7 @@ typedef struct {
     Dt_t*     chans;
 } chanItem;
 
-static void
-freeChannel (Dt_t* d, channel* cp, Dtdisc_t* disc)
-{
-    (void)d;
+static void freeChannel(channel *cp, Dtdisc_t *disc) {
     (void)disc;
 
     free_graph (cp->G);
@@ -265,10 +262,7 @@ freeChannel (Dt_t* d, channel* cp, Dtdisc_t* disc)
     free (cp);
 }
 
-static void
-freeChanItem (Dt_t* d, chanItem* cp, Dtdisc_t* disc)
-{
-    (void)d;
+static void freeChanItem(chanItem *cp, Dtdisc_t *disc) {
     (void)disc;
 
     dtclose (cp->chans);
@@ -320,8 +314,6 @@ static Dtdisc_t chanDisc = {
     (Dtfree_f)freeChannel,
     (Dtcompar_f)chancmpid,
     0,
-    0,
-    0
 };
 
 static Dtdisc_t chanItemDisc = {
@@ -332,8 +324,6 @@ static Dtdisc_t chanItemDisc = {
     (Dtfree_f)freeChanItem,
     (Dtcompar_f)dcmpid,
     0,
-    0,
-    0
 };
 
 static void
@@ -844,9 +834,9 @@ is_parallel(segment* s1, segment* s2)
 static int
 decide_point(pair *ret, segment* si, segment* sj, int dir1, int dir2)
 {
-    int prec, ans = 0, temp;
+    int prec = 0, ans = 0, temp;
     segment* np1;
-    segment* np2;
+    segment *np2 = NULL;
     
     while ((np1 = next_seg(si,dir1)) && (np2 = next_seg(sj,dir2)) &&
 	is_parallel(np1, np2)) {
@@ -1411,7 +1401,7 @@ static char* prolog2 =
 static char* epilog2 =
 "showpage\n\
 %%%%Trailer\n\
-%%%%BoundingBox: %d %d %d %d\n";
+%%%%BoundingBox: %.f %.f %.f %.f\n";
 
 static point
 coordOf (cell* cp, snode* np)
@@ -1536,7 +1526,6 @@ static DEBUG_FN void emitSearchGraph(FILE *fp, sgraph *sg) {
 static DEBUG_FN void emitGraph(FILE *fp, maze *mp, size_t n_edges,
                                route *route_list, epair_t es[]) {
     boxf bb, absbb;
-    box bbox;
 
     absbb.LL.x = absbb.LL.y = MAXDOUBLE;
     absbb.UR.x = absbb.UR.y = -MAXDOUBLE;
@@ -1564,6 +1553,7 @@ static DEBUG_FN void emitGraph(FILE *fp, maze *mp, size_t n_edges,
       absbb.UR.y = MAX(absbb.UR.y, bb.UR.y);
     }
 
+    boxf bbox;
     bbox.LL.x = absbb.LL.x + TRANS;
     bbox.LL.y = absbb.LL.y + TRANS;
     bbox.UR.x = absbb.UR.x + TRANS;
