@@ -1,20 +1,13 @@
-/* $Id$Revision: */
-/* vim:set shiftwidth=4 ts=8: */
-
 /**********************************************************
 *      See the LICENSE file for copyright infomation.     *
 **********************************************************/
 
-#ifndef RED_BLACK_TREE_H
-#define RED_BLACK_TREE_H
+#pragma once
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#include "misc.h"
-#include "stack.h"
-
 /*  CONVENTIONS:  All data structures for red-black trees have the prefix */
 /*                "rb_" to prevent name conflicts. */
 /*                                                                      */
@@ -30,10 +23,6 @@ extern "C" {
 /*                names beginning with "g".  An example of a global */
 /*                variable name is gNewtonsConstant. */
 
-/* comment out the line below to remove all the debugging assertion */
-/* checks from the compiled code.  */
-/* #define DEBUG_ASSERT 1 */
-
 typedef struct rb_red_blk_node {
   void* key;
   void* info;
@@ -50,8 +39,6 @@ typedef struct rb_red_blk_tree {
   int (*Compare)(const void* a, const void* b); 
   void (*DestroyKey)(void* a);
   void (*DestroyInfo)(void* a);
-  void (*PrintKey)(const void* a);
-  void (*PrintInfo)(void* a);
   /*  A sentinel is used for root and for nil.  These sentinels are */
   /*  created when RBTreeCreate is caled.  root->left should always */
   /*  point to the node which is the root of the tree.  nil points to a */
@@ -64,21 +51,14 @@ typedef struct rb_red_blk_tree {
 
 rb_red_blk_tree* RBTreeCreate(int  (*CompFunc)(const void*, const void*),
 			     void (*DestFunc)(void*), 
-			     void (*InfoDestFunc)(void*), 
-			     void (*PrintFunc)(const void*),
-			     void (*PrintInfo)(void*));
+			     void (*InfoDestFunc)(void*));
 rb_red_blk_node * RBTreeInsert(rb_red_blk_tree*, void* key, void* info);
-void RBTreePrint(rb_red_blk_tree*);
 void RBDelete(rb_red_blk_tree* , rb_red_blk_node* );
 void RBTreeDestroy(rb_red_blk_tree*);
 rb_red_blk_node* TreePredecessor(rb_red_blk_tree*,rb_red_blk_node*);
 rb_red_blk_node* TreeSuccessor(rb_red_blk_tree*,rb_red_blk_node*);
 rb_red_blk_node* RBExactQuery(rb_red_blk_tree*, void*);
-stk_stack * RBEnumerate(rb_red_blk_tree* tree,void* low, void* high);
-void NullFunction(void*);
 
 #ifdef __cplusplus
 }
 #endif
-
-#endif
