@@ -44,7 +44,8 @@ typedef  StressMajorizationSmoother TriangleSmoother;
 
 void TriangleSmoother_delete(TriangleSmoother sm);
 
-TriangleSmoother TriangleSmoother_new(SparseMatrix A, int dim, double lambda, double *x, int use_triangularization);
+TriangleSmoother TriangleSmoother_new(SparseMatrix A, int dim, double *x,
+                                      int use_triangularization);
 
 void TriangleSmoother_smooth(TriangleSmoother sm, int dim, double *x);
 
@@ -66,7 +67,7 @@ void SpringSmoother_delete(SpringSmoother sm);
 void SpringSmoother_smooth(SpringSmoother sm, SparseMatrix A, int dim, double *x);
 /*------------------------------------------------------------------*/
 
-void post_process_smoothing(int dim, SparseMatrix A, spring_electrical_control ctrl, double *x, int *flag);
+void post_process_smoothing(int dim, SparseMatrix A, spring_electrical_control ctrl, double *x);
 
 /*-------------------- sparse stress majorizationp ------------------- */
 typedef  StressMajorizationSmoother SparseStressMajorizationSmoother;
@@ -75,9 +76,9 @@ typedef  StressMajorizationSmoother SparseStressMajorizationSmoother;
 
 void SparseStressMajorizationSmoother_delete(SparseStressMajorizationSmoother sm);
 
-enum {WEIGHTING_SCHEME_NONE, WEIGHTING_SCHEME_SQR_DIST};
-SparseStressMajorizationSmoother SparseStressMajorizationSmoother_new(SparseMatrix A, int dim, double lambda, double *x, 
-								      int weighting_scheme);
+SparseStressMajorizationSmoother
+SparseStressMajorizationSmoother_new(SparseMatrix A, int dim, double lambda,
+                                     double *x);
 
 double SparseStressMajorizationSmoother_smooth(SparseStressMajorizationSmoother sm, int dim, double *x, int maxit_sm, double tol);
 
