@@ -353,9 +353,8 @@ xdot *parseXDotFOn(char *s, drawfunc_t fns[], size_t sz, xdot *x) {
 	ops = gv_calloc(XDBSIZE, sz);
     }
     else {
-	ops = (char*)(x->ops);
 	bufsz = initcnt + XDBSIZE;
-	ops = gv_recalloc(ops, initcnt, bufsz, sz);
+	ops = gv_recalloc(x->ops, initcnt, bufsz, sz);
     }
 
     while ((s = parseOp(&op, s, fns, &error))) {
@@ -984,5 +983,8 @@ void freeXDotColor (xdot_color* cp)
 
 /**
  * @dir lib/xdot
- * @brief API xdot/xdot.h
+ * @brief parsing and deparsing of xdot operations, API xdot.h
+ *
+ * [man 3 xdot](https://graphviz.org/pdf/xdot.3.pdf)
+ *
  */
