@@ -53,9 +53,9 @@ typedef struct {
 } gvid_t;
 
 #define ID "id"
-#define ND_gid(n) (((gvid_t*)aggetrec(n, ID, FALSE))->id) 
-#define ED_gid(n) (((gvid_t*)aggetrec(n, ID, FALSE))->id) 
-#define GD_gid(n) (((gvid_t*)aggetrec(n, ID, FALSE))->id) 
+#define ND_gid(n) (((gvid_t*)aggetrec(n, ID, 0))->id) 
+#define ED_gid(n) (((gvid_t*)aggetrec(n, ID, 0))->id) 
+#define GD_gid(n) (((gvid_t*)aggetrec(n, ID, 0))->id) 
 
 static bool IS_CLUSTER(Agraph_t *s) {
   return startswith(agnameof(s), "cluster");
@@ -594,9 +594,7 @@ typedef struct {
     int v;
 } intm;
 
-static void freef(Dt_t * dt, intm * obj, Dtdisc_t * disc)
-{
-    (void)dt;
+static void freef(intm *obj, Dtdisc_t *disc) {
     (void)disc;
     free(obj->id);
     free(obj);
@@ -610,8 +608,6 @@ static Dtdisc_t intDisc = {
     (Dtfree_f) freef,
     (Dtcompar_f) NULL,
     0,
-    0,
-    0
 };
 
 static int lookup (Dt_t* map, char* name)
@@ -631,7 +627,7 @@ static void insert (Dt_t* map, char* name, int v)
 	return;
     }
     ip = gv_alloc(sizeof(intm));
-    ip->id = strdup(name);
+    ip->id = gv_strdup(name);
     ip->v = v;
     dtinsert (map, ip);
 }
@@ -662,9 +658,9 @@ static void write_graph(Agraph_t *g, GVJ_t *job, bool top, state_t *sp) {
 
     if (top) {
 	map = dtopen (&intDisc, Dtoset);
-	aginit(g, AGNODE, ID, sizeof(gvid_t), FALSE);
-	aginit(g, AGEDGE, ID, sizeof(gvid_t), FALSE);
-	aginit(g, AGRAPH, ID, -((int)sizeof(gvid_t)), FALSE);
+	aginit(g, AGNODE, ID, sizeof(gvid_t), false);
+	aginit(g, AGEDGE, ID, sizeof(gvid_t), false);
+	aginit(g, AGRAPH, ID, -((int)sizeof(gvid_t)), false);
 	sgcnt = label_subgs(g, sgcnt, map);
 	for (np = agfstnode(g); np; np = agnxtnode(g,np)) {
 	    if (IS_CLUST_NODE(np)) {
