@@ -163,22 +163,34 @@ static void svg_grstyle(GVJ_t * job, int filled, int gid)
 
     gvputs(job, " fill=\"");
     if (filled == GRADIENT) {
-	gvprintf(job, "url(#l_%d)", gid);
+	gvputs(job, "url(#");
+	if (obj->id != NULL) {
+	    gvputs_xml(job, obj->id);
+	    gvputc(job, '_');
+	}
+	gvprintf(job, "l_%d)", gid);
     } else if (filled == RGRADIENT) {
-	gvprintf(job, "url(#r_%d)", gid);
+	gvputs(job, "url(#");
+	if (obj->id != NULL) {
+	    gvputs_xml(job, obj->id);
+	    gvputc(job, '_');
+	}
+	gvprintf(job, "r_%d)", gid);
     } else if (filled) {
 	svg_print_paint(job, obj->fillcolor);
 	if (obj->fillcolor.type == RGBA_BYTE
 	    && obj->fillcolor.u.rgba[3] > 0
 	    && obj->fillcolor.u.rgba[3] < 255)
 	    gvprintf(job, "\" fill-opacity=\"%f",
-		     ((float) obj->fillcolor.u.rgba[3] / 255.0));
+		     (float)obj->fillcolor.u.rgba[3] / 255.0);
     } else {
 	gvputs(job, "none");
     }
     gvputs(job, "\" stroke=\"");
     svg_print_paint(job, obj->pencolor);
-    if (obj->penwidth != PENWIDTH_NORMAL) {
+    // will `gvprintdouble` output something different from `PENWIDTH_NORMAL`?
+    const double GVPRINT_DOUBLE_THRESHOLD = 0.005;
+    if (!(fabs(obj->penwidth - PENWIDTH_NORMAL) < GVPRINT_DOUBLE_THRESHOLD)) {
 	gvputs(job, "\" stroke-width=\"");
         gvprintdouble(job, obj->penwidth);
     }
@@ -190,7 +202,7 @@ static void svg_grstyle(GVJ_t * job, int filled, int gid)
     if (obj->pencolor.type == RGBA_BYTE && obj->pencolor.u.rgba[3] > 0
 	&& obj->pencolor.u.rgba[3] < 255)
 	gvprintf(job, "\" stroke-opacity=\"%f",
-		 ((float) obj->pencolor.u.rgba[3] / 255.0));
+		 (float)obj->pencolor.u.rgba[3] / 255.0);
 
     gvputc(job, '"');
 }
@@ -463,29 +475,29 @@ static void svg_textspan(GVJ_t * job, pointf p, textspan_t * span)
 	    gvprintf(job, " font-style=\"%s\"", style);
     } else
 	gvprintf(job, " font-family=\"%s\"", span->font->name);
-    if ((span->font) && (flags = span->font->flags)) {
+    if ((flags = span->font->flags)) {
 	if ((flags & HTML_BF) && !weight)
 	    gvputs(job, " font-weight=\"bold\"");
 	if ((flags & HTML_IF) && !style)
 	    gvputs(job, " font-style=\"italic\"");
-	if ((flags & (HTML_UL|HTML_S|HTML_OL))) {
+	if (flags & (HTML_UL|HTML_S|HTML_OL)) {
 	    int comma = 0;
 	    gvputs(job, " text-decoration=\"");
 	    if ((flags & HTML_UL)) {
 		gvputs(job, "underline");
 		comma = 1;
 	    }
-	    if ((flags & HTML_OL)) {
+	    if (flags & HTML_OL) {
 		gvprintf(job, "%soverline", (comma?",":""));
 		comma = 1;
 	    }
-	    if ((flags & HTML_S))
+	    if (flags & HTML_S)
 		gvprintf(job, "%sline-through", (comma?",":""));
 	    gvputc(job, '"');
 	}
-	if ((flags & HTML_SUP))
+	if (flags & HTML_SUP)
 	    gvputs(job, " baseline-shift=\"super\"");
-	if ((flags & HTML_SUB))
+	if (flags & HTML_SUB)
 	    gvputs(job, " baseline-shift=\"sub\"");
     }
 
@@ -500,7 +512,7 @@ static void svg_textspan(GVJ_t * job, pointf p, textspan_t * span)
 		 obj->pencolor.u.rgba[0], obj->pencolor.u.rgba[1],
 		 obj->pencolor.u.rgba[2]);
 	if (obj->pencolor.u.rgba[3] < 255)
-	    gvprintf(job, " fill-opacity=\"%f\"", ((float) obj->pencolor.u.rgba[3] / 255.0));
+	    gvprintf(job, " fill-opacity=\"%f\"", (float)obj->pencolor.u.rgba[3] / 255.0);
 	break;
     default:
 	UNREACHABLE(); // internal error
@@ -522,16 +534,16 @@ static void svg_textspan(GVJ_t * job, pointf p, textspan_t * span)
 
 static void svg_print_stop(GVJ_t * job, double offset, gvcolor_t color)
 {
-    if (offset == 0.0)
+    if (fabs(offset - 0.0) < 0.0005)
 	gvputs(job, "<stop offset=\"0\" style=\"stop-color:");
-    else if (offset == 1.0)
+    else if (fabs(offset - 1.0) < 0.0005)
 	gvputs(job, "<stop offset=\"1\" style=\"stop-color:");
     else
 	gvprintf(job, "<stop offset=\"%.03f\" style=\"stop-color:", offset);
     svg_print_gradient_color(job, color);
     gvputs(job, ";stop-opacity:");
     if (color.type == RGBA_BYTE && color.u.rgba[3] < 255)
-	gvprintf(job, "%f", ((float) color.u.rgba[3] / 255.0));
+	gvprintf(job, "%f", (float)color.u.rgba[3] / 255.0);
     else if (color.type == COLOR_STRING && !strcmp(color.u.string, transparent))
 	gvputs(job, "0");
     else
@@ -586,10 +598,10 @@ static int svg_rgradstyle(GVJ_t * job)
     int id = rgradId++;
 
     obj_state_t *obj = job->obj;
-    double angle = obj->gradient_angle * M_PI / 180;	//angle of gradient line
-    if (angle == 0.) {
+    if (obj->gradient_angle == 0) {
 	ifx = ify = 50;
     } else {
+	double angle = obj->gradient_angle * M_PI / 180;	//angle of gradient line
 	ifx = round(50 * (1 + cos(angle)));
 	ify = round(50 * (1 - sin(angle)));
     }
@@ -617,7 +629,7 @@ static void svg_ellipse(GVJ_t * job, pointf * A, int filled)
     /* A[] contains 2 points: the center and corner. */
     if (filled == GRADIENT) {
 	gid = svg_gradstyle(job, A, 2);
-    } else if (filled == (RGRADIENT)) {
+    } else if (filled == RGRADIENT) {
 	gid = svg_rgradstyle(job);
     }
     gvputs(job, "<ellipse");
@@ -634,18 +646,13 @@ static void svg_ellipse(GVJ_t * job, pointf * A, int filled)
 }
 
 static void
-svg_bezier(GVJ_t * job, pointf * A, int n, int arrow_at_start,
-	   int arrow_at_end, int filled)
-{
-    (void)arrow_at_start;
-    (void)arrow_at_end;
-
+svg_bezier(GVJ_t *job, pointf *A, int n, int filled) {
     int gid = 0;
     obj_state_t *obj = job->obj;
   
     if (filled == GRADIENT) {
 	gid = svg_gradstyle(job, A, n);
-    } else if (filled == (RGRADIENT)) {
+    } else if (filled == RGRADIENT) {
 	gid = svg_rgradstyle(job);
     }
     gvputs(job, "<path");
@@ -665,7 +672,7 @@ static void svg_polygon(GVJ_t * job, pointf * A, int n, int filled)
     int i, gid = 0;
     if (filled == GRADIENT) {
 	gid = svg_gradstyle(job, A, n);
-    } else if (filled == (RGRADIENT)) {
+    } else if (filled == RGRADIENT) {
 	gid = svg_rgradstyle(job);
     }
     gvputs(job, "<polygon");
@@ -809,7 +816,7 @@ gvplugin_installed_t gvrender_svg_types[] = {
 
 gvplugin_installed_t gvdevice_svg_types[] = {
     {FORMAT_SVG, "svg:svg", 1, NULL, &device_features_svg},
-#if HAVE_LIBZ
+#ifdef HAVE_LIBZ
     {FORMAT_SVGZ, "svgz:svg", 1, NULL, &device_features_svgz},
 #endif
     {0, NULL, 0, NULL, NULL}
