@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,44 +5,42 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #include "simple.h"
 #include <stdio.h>
 #include <stdlib.h>
+#include <cgraph/alloc.h>
+#include <cgraph/exit.h>
 
 void find_intersection(struct vertex *l, struct vertex *m,
 		       struct intersection ilist[], struct data *input);
-static int gt(struct vertex **i, struct vertex **j);
+static int gt(const void *a, const void *b);
 
 void find_ints(struct vertex vertex_list[],
-	struct polygon polygon_list[],
 	struct data *input,
 	struct intersection ilist[])
 {
-    int i, j, k;
+    int j, k;
     struct active_edge_list all;
-    struct active_edge *new, *tempa;
-    struct vertex *pt1, *pt2, *templ, **pvertex;
-/*      char *malloc(); */
+    struct active_edge *tempa;
+    struct vertex *pt1, *pt2, *templ;
 
     input->ninters = 0;
-    all.first = all.final = NIL;
+    all.first = all.final = NULL;
     all.number = 0;
 
-    pvertex = (struct vertex **)
-	malloc((input->nvertices) * sizeof(struct vertex *));
+    struct vertex **pvertex = gv_calloc(input->nvertices, sizeof(struct vertex*));
 
-    for (i = 0; i < input->nvertices; i++)
+    for (size_t i = 0; i < input->nvertices; i++)
 	pvertex[i] = vertex_list + i;
 
 /* sort vertices by x coordinate	*/
-    qsort(pvertex, input->nvertices, sizeof(struct vertex *),
-    	  (int (*)(const void *, const void *))gt);
+    qsort(pvertex, input->nvertices, sizeof(struct vertex *), gt);
 
 /* walk through the vertices in order of increasing x coordinate	*/
-    for (i = 0; i < input->nvertices; i++) {
+    for (size_t i = 0; i < input->nvertices; i++) {
 	pt1 = pvertex[i];
 	templ = pt2 = prior(pvertex[i]);
 	for (k = 0; k < 2; k++) {	/* each vertex has 2 edges */
@@ -57,12 +52,10 @@ void find_ints(struct vertex vertex_list[],
 		     j++, tempa = tempa->next)
 		    find_intersection(tempa->name, templ, ilist, input);	/* test */
 
-		new =
-		    (struct active_edge *)
-		    malloc(sizeof(struct active_edge));
+		struct active_edge *new = gv_alloc(sizeof(struct active_edge));
 		if (all.number == 0) {
 		    all.first = new;
-		    new->last = NIL;
+		    new->last = NULL;
 		} /* insert */
 		else {
 		    all.final->next = new;
@@ -70,7 +63,7 @@ void find_ints(struct vertex vertex_list[],
 		}
 
 		new->name = templ;
-		new->next = NIL;
+		new->next = NULL;
 		templ->active = new;
 		all.final = new;
 		all.number++;
@@ -79,28 +72,30 @@ void find_ints(struct vertex vertex_list[],
 
 	    case 1:		/* backward edge, delete        */
 
-		if ((tempa = templ->active) == NIL) {
+		if ((tempa = templ->active) == NULL) {
 		    fprintf(stderr,
 			    "\n***ERROR***\n trying to delete a non line\n");
-		    exit(1);
+		    graphviz_exit(1);
 		}
 		if (all.number == 1)
-		    all.final = all.first = NIL;	/* delete the line */
+		    all.final = all.first = NULL;	/* delete the line */
 		else if (tempa == all.first) {
 		    all.first = all.first->next;
-		    all.first->last = NIL;
+		    all.first->last = NULL;
 		} else if (tempa == all.final) {
 		    all.final = all.final->last;
-		    all.final->next = NIL;
+		    all.final->next = NULL;
 		} else {
 		    tempa->last->next = tempa->next;
 		    tempa->next->last = tempa->last;
 		}
-		free((char *) tempa);
+		free(tempa);
 		all.number--;
-		templ->active = NIL;
+		templ->active = NULL;
 		break;		/* end of case 1        */
 
+	    default:
+		break;
 	    }			/* end switch   */
 
 	    pt2 = after(pvertex[i]);
@@ -110,13 +105,20 @@ void find_ints(struct vertex vertex_list[],
     free(pvertex);
 }
 
-static int gt(struct vertex **i, struct vertex **j)
-{				/* i > j if i.x > j.x or i.x = j.x and i.y > j.y  */
-    double t;
-    if ((t = (*i)->pos.x - (*j)->pos.x) != 0.)
-	return ((t > 0.) ? 1 : -1);
-    if ((t = (*i)->pos.y - (*j)->pos.y) == 0.)
-	return (0);
-    else
-	return ((t > 0.) ? 1 : -1);
+static int gt(const void *a, const void *b) {
+    const struct vertex *const *i = a;
+    const struct vertex *const *j = b;
+    if ((*i)->pos.x > (*j)->pos.x) {
+      return 1;
+    }
+    if ((*i)->pos.x < (*j)->pos.x) {
+      return -1;
+    }
+    if ((*i)->pos.y > (*j)->pos.y) {
+      return 1;
+    }
+    if ((*i)->pos.y < (*j)->pos.y) {
+      return -1;
+    }
+    return 0;
 }
